@@ -1,26 +1,15 @@
 package Net::Amazon::S3::Request::DeleteObject;
-$Net::Amazon::S3::Request::DeleteObject::VERSION = '0.84';
+$Net::Amazon::S3::Request::DeleteObject::VERSION = '0.87';
 use Moose 0.85;
 use Moose::Util::TypeConstraints;
-extends 'Net::Amazon::S3::Request';
+extends 'Net::Amazon::S3::Request::Object';
 
 # ABSTRACT: An internal class to delete an object
 
-with 'Net::Amazon::S3::Role::Bucket';
-
-has 'key'    => ( is => 'ro', isa => 'Str',        required => 1 );
+with 'Net::Amazon::S3::Request::Role::HTTP::Method::DELETE';
 
 __PACKAGE__->meta->make_immutable;
 
-sub http_request {
-    my $self = shift;
-
-    return $self->_build_http_request(
-        method => 'DELETE',
-        path   => $self->_uri( $self->key ),
-    );
-}
-
 1;
 
 __END__
@@ -35,7 +24,7 @@ Net::Amazon::S3::Request::DeleteObject - An internal class to delete an object
 
 =head1 VERSION
 
-version 0.84
+version 0.87
 
 =head1 SYNOPSIS
 
@@ -63,7 +52,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
