@@ -1,6 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Operation::Bucket::Objects::List;
 # ABSTRACT: used for testing and as example
-$Shared::Examples::Net::Amazon::S3::Operation::Bucket::Objects::List::VERSION = '0.86';
+$Shared::Examples::Net::Amazon::S3::Operation::Bucket::Objects::List::VERSION = '0.87';
 use strict;
 use warnings;
 
@@ -12,6 +12,7 @@ our @EXPORT_OK = (
     qw[ list_bucket_objects_v1_with_filter ],
     qw[ list_bucket_objects_v1_with_delimiter ],
     qw[ list_bucket_objects_v1_with_prefix_and_delimiter ],
+    qw[ list_bucket_objects_v1_google_cloud_storage ],
 );
 
 sub list_bucket_objects_v1 {
@@ -168,6 +169,35 @@ sub list_bucket_objects_v1_with_prefix_and_delimiter {
 EOXML
 }
 
+sub list_bucket_objects_v1_google_cloud_storage {
+    <<'EOXML';
+<?xml version="1.0" encoding="UTF-8"?>
+<ListBucketResult xmlns='http://doc.s3.amazonaws.com/2006-03-01'>
+  <Name>gcs-bucket</Name>
+  <Prefix></Prefix>
+  <Marker></Marker>
+  <NextMarker>next/marker/is/foo</NextMarker>
+  <IsTruncated>true</IsTruncated>
+  <Contents>
+    <Key>path/to/value</Key>
+    <Generation>1473499153424000</Generation>
+    <MetaGeneration>1</MetaGeneration>
+    <LastModified>2017-04-21T22:06:03.413Z</LastModified>
+    <ETag>"1f52bad2879ca96dacd7a40f33001230"</ETag>
+    <Size>742213</Size>
+  </Contents>
+  <Contents>
+    <Key>path/to/value2</Key>
+    <Generation>1473499153424001</Generation>
+    <MetaGeneration>1</MetaGeneration>
+    <LastModified>2018-04-21T22:06:03.413Z</LastModified>
+    <ETag>"1f52bad2889ca96dacd7a40f33001230"</ETag>
+    <Size>742214</Size>
+  </Contents>
+</ListBucketResult>
+EOXML
+}
+
 1;
 
 __END__
@@ -182,7 +212,7 @@ Shared::Examples::Net::Amazon::S3::Operation::Bucket::Objects::List - used for t
 
 =head1 VERSION
 
-version 0.86
+version 0.87
 
 =head1 AUTHOR
 
